import type { ShapeDrawerAfterEffectFunction, ShapeDrawerDestroyFunction, ShapeDrawerDrawFunction, ShapeDrawerInitFunction } from "../Types/ShapeDrawerFunctions";
import { Container } from "./Container";
import type { CustomEventArgs } from "../Types/CustomEventArgs";
import type { CustomEventListener } from "../Types/CustomEventListener";
import type { IContainerPlugin } from "./Interfaces/IContainerPlugin";
import type { IInteractor } from "./Interfaces/IInteractor";
import type { ILoadParams } from "./Interfaces/ILoadParams";
import type { IMovePathGenerator } from "./Interfaces/IMovePathGenerator";
import type { IOptions } from "../Options/Interfaces/IOptions";
import type { IParticleMover } from "./Interfaces/IParticleMover";
import type { IParticleUpdater } from "./Interfaces/IParticleUpdater";
import type { IParticlesOptions } from "../Options/Interfaces/Particles/IParticlesOptions";
import type { IPlugin } from "./Interfaces/IPlugin";
import type { IShapeDrawer } from "./Interfaces/IShapeDrawer";
import type { ISourceOptions } from "../Types/ISourceOptions";
import type { Options } from "../Options/Classes/Options";
import type { Particle } from "./Particle";
import type { ParticlesOptions } from "../Options/Classes/Particles/ParticlesOptions";
import type { RecursivePartial } from "../Types/RecursivePartial";
import type { SingleOrMultiple } from "../Types/SingleOrMultiple";
declare global {
    interface Window {
        tsParticles: Engine;
    }
}
export declare class Engine {
    readonly drawers: Map<string, IShapeDrawer>;
    readonly interactors: Map<Container, IInteractor[]>;
    readonly movers: Map<Container, IParticleMover[]>;
    readonly pathGenerators: Map<string, IMovePathGenerator>;
    readonly plugins: IPlugin[];
    readonly presets: Map<string, RecursivePartial<IOptions>>;
    readonly updaters: Map<Container, IParticleUpdater[]>;
    private readonly _configs;
    private readonly _domArray;
    private readonly _eventDispatcher;
    private _initialized;
    private readonly _initializers;
    constructor();
    get configs(): Record<string, ISourceOptions>;
    get version(): string;
    addConfig(nameOrConfig: string | ISourceOptions, config?: ISourceOptions): void;
    addEventListener(type: string, listener: CustomEventListener): void;
    addInteractor(name: string, interactorInitializer: (container: Container) => IInteractor, refresh?: boolean): Promise<void>;
    addMover(name: string, moverInitializer: (container: Container) => IParticleMover, refresh?: boolean): Promise<void>;
    addParticleUpdater(name: string, updaterInitializer: (container: Container) => IParticleUpdater, refresh?: boolean): Promise<void>;
    addPathGenerator(name: string, generator: IMovePathGenerator, refresh?: boolean): Promise<void>;
    addPlugin(plugin: IPlugin, refresh?: boolean): Promise<void>;
    addPreset(preset: string, options: RecursivePartial<IOptions>, override?: boolean, refresh?: boolean): Promise<void>;
    addShape(shape: SingleOrMultiple<string>, drawer: IShapeDrawer | ShapeDrawerDrawFunction, initOrRefresh?: ShapeDrawerInitFunction | boolean, afterEffectOrRefresh?: ShapeDrawerAfterEffectFunction | boolean, destroyOrRefresh?: ShapeDrawerDestroyFunction | boolean, refresh?: boolean): Promise<void>;
    clearPlugins(container: Container): void;
    dispatchEvent(type: string, args: CustomEventArgs): void;
    dom(): Container[];
    domItem(index: number): Container | undefined;
    getAvailablePlugins(container: Container): Map<string, IContainerPlugin>;
    getInteractors(container: Container, force?: boolean): IInteractor[];
    getMovers(container: Container, force?: boolean): IParticleMover[];
    getPathGenerator(type: string): IMovePathGenerator | undefined;
    getPlugin(plugin: string): IPlugin | undefined;
    getPreset(preset: string): ISourceOptions | undefined;
    getShapeDrawer(type: string): IShapeDrawer | undefined;
    getSupportedShapes(): IterableIterator<string>;
    getUpdaters(container: Container, force?: boolean): IParticleUpdater[];
    init(): void;
    load(params: ILoadParams): Promise<Container | undefined>;
    loadOptions(options: Options, sourceOptions: ISourceOptions): void;
    loadParticlesOptions(container: Container, options: ParticlesOptions, ...sourceOptions: (RecursivePartial<IParticlesOptions> | undefined)[]): void;
    refresh(refresh?: boolean): Promise<void>;
    removeEventListener(type: string, listener: CustomEventListener): void;
    setOnClickHandler(callback: (e: Event, particles?: Particle[]) => void): void;
}
